<?xml version="1.0"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:isocat="http://www.isocat.org/" xmlns:dcif="http://www.isocat.org/ns/dcif" exclude-result-prefixes="#all">

	<xsl:param name="debug" select="'t'"/>
	<xsl:param name="standard" select="'f'"/>

	<xsl:variable name="debug-flag" select="$debug='t'"/>
	<xsl:variable name="standard-flag" select="$standard='t' or //dcif:dataCategory/dcif:administrationInformationSection/dcif:administrationRecord/dcif:registrationStatus!='private'"/>
	
	<xsl:variable name="languages" select="doc('active:ISOcat.access.data.dm.languages')" use-when="system-property('ten60.pid')!=''"/>
	<xsl:variable name="languages" select="doc('http://localhost:8080/isocat/rest/info/languages.xml')" use-when="system-property('ten60.pid')=''"/>
	
	<xsl:template match="text()"/>
	
	<xsl:template name="fatal">
		<xsl:param name="msg"/>
		<fatal>
			<xsl:value-of select="$msg"/>
		</fatal>
	</xsl:template>
	
	<xsl:template name="error">
		<xsl:param name="msg"/>
		<error>
			<xsl:value-of select="$msg"/>
		</error>
	</xsl:template>

	<xsl:template name="warning">
		<xsl:param name="msg"/>
		<xsl:param name="standard" select="'disallow'"/>
		<warning standard="{$standard}">
			<xsl:value-of select="$msg"/>
		</warning>
	</xsl:template>
	
	<xsl:template name="error-or-warning">
		<xsl:param name="msg"/>
		<xsl:choose>
			<xsl:when test="$standard-flag">
				<xsl:call-template name="error">
					<xsl:with-param name="msg" select="$msg"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="warning">
					<xsl:with-param name="msg" select="$msg"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template match="dcif:dataCategory">
		<xsl:if test="@isocat:type='unknown'">
			<xsl:call-template name="fatal">
				<xsl:with-param name="msg">The type of the Data Category is unknown.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="@type='complex'">
			<xsl:choose>
				<xsl:when test="empty(dcif:conceptualDomain)">
					<xsl:call-template name="error">
						<xsl:with-param name="msg">The complex Data Category does not have the mandatory conceptual domain.</xsl:with-param>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="@type='simple'">
			<xsl:variable name="context" select="document(concat('active:ISOcat.access.data.dc.context+dc@data:text/plain,',@isocat:id))" use-when="system-property('ten60.pid')!=''"/>
			<xsl:variable name="context" select="document(concat('http://localhost:8080/isocat/rest/dc/,',@isocat:id,'/context'))" use-when="system-property('ten60.pid')=''"/>
			<xsl:if test="empty($context//domain/@dc)">
				<xsl:call-template name="error-or-warning">
					<xsl:with-param name="msg">The simple Data Category does not belong to any profile specific closed value domain.</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:variable name="dataTypes" select="distinct-values((dcif:conceptualDomain/dcif:dataType,dcif:linguisticSection/dcif:conceptualDomain/dcif:dataType))"/>
		<xsl:if test="count($dataTypes)>1">
			<xsl:call-template name="error">
				<xsl:with-param name="msg">
					<xsl:text>The complex Data Category contains conceptual domains with different data types, i.e., </xsl:text>
					<xsl:value-of select="string-join(subsequence($dataTypes,1,count($dataTypes) - 1),', ')"/>
					<xsl:text> or </xsl:text>
					<xsl:value-of select="$dataTypes[last()]"/>
					<xsl:text>.</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:for-each-group select="dcif:conceptualDomain" group-by="dcif:schemaType">
			<xsl:if test="count(current-group()) > 1">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>The Data Category contains more then one constrained conceptual domain for the schema type '</xsl:text>
						<xsl:value-of select="current-grouping-key()"/>
						<xsl:text>'.</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each-group>
		<xsl:for-each-group select="dcif:conceptualDomain" group-by="dcif:profile">
			<xsl:if test="count(current-group()) > 1">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>The Data Category contains more then one conceptual domain for the profile '</xsl:text>
						<xsl:value-of select="current-grouping-key()"/>
						<xsl:text>'.</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each-group>
		<xsl:for-each-group select="dcif:linguisticSection" group-by="dcif:language">
			<xsl:if test="count(current-group()) > 1">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>The Data Category contains more then one linguistic section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current-grouping-key()]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="current-grouping-key()"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each-group>
		<xsl:if test="count(dcif:conceptualDomain[@type='open']) > 1">
			<xsl:call-template name="error">
				<xsl:with-param name="msg">The Data Category contains more then one open conceptual domain.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:administrationRecord">
		<xsl:if test="empty(dcif:justification)">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">The Data Category has no justification why it should be included in the Data Category Registry.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="empty(isocat:change) and empty(dcif:creation)">
			<xsl:call-template name="error">
				<xsl:with-param name="msg">The Data Category has no change history. There should be at least one change description, which documents the creation of the Data Category.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:justification">
		<xsl:if test="normalize-space(.)=''">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">Empty justification why the Data Category should be included in the Data Category Registry.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:identifier">
		<xsl:if test="contains(.,':') or not(matches(.,'^(\p{L}|_)([^:]*)'))">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">The identifier of this Data Category is not a valid NCName, i.e., can not be used as the local part of an XML element name. Some XML-based export formats try to use the identifier to create valid QNames.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:dataElementNameSection">
		<xsl:choose>
			<xsl:when test="empty(*)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">Unspecified data element name section.</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="empty(dcif:dataElementName)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">Unspecified data element name in a data element name section.</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="empty(dcif:source)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">Unspecified source in a data element name section.</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:dataElementNameSection/dcif:dataElementName">
		<xsl:if test="normalize-space(.)=''">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">Empty data element name in a data element name section.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:dataElementNameSection/dcif:source">
		<xsl:if test="normalize-space(.)=''">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">Empty source in a data element name section.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:descriptionSection">
		<xsl:if test="empty(dcif:languageSection[dcif:language='en'])">
			<xsl:call-template name="error">
				<xsl:with-param name="msg">The Data Category does not include the mandatory English (en) language section.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:for-each-group select="dcif:languageSection" group-by="dcif:language">
			<xsl:if test="count(current-group()) > 1">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>The Data Category contains more then one language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current-grouping-key()]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="current-grouping-key()"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each-group>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:descriptionSection/dcif:profile">
		<xsl:if test="current()='undecided'">
			<xsl:choose>
				<xsl:when test="count(distinct-values(../dcif:profile))=1">
					<xsl:call-template name="warning">
						<xsl:with-param name="msg">This data category is (still) a member of the 'undecided' profile.</xsl:with-param>
						<xsl:with-param name="standard" select="'allow'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="error">
						<xsl:with-param name="msg">This data category is a member of the 'undecided' profile and one or more thematic profiles.</xsl:with-param>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="$standard-flag and current()='undecided'">
			<xsl:call-template name="error">
				<xsl:with-param name="msg">Standardized data categories can't be a member of the 'undecided' profile.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$standard-flag and current()='not available'">
			<xsl:choose>
				<xsl:when test="ancestor::dcif:dataCategory/@isocat:type='closed'">
					<xsl:call-template name="warning">
						<xsl:with-param name="msg">Standardized data categories can't be a member of the 'not available' profile.</xsl:with-param>
						<xsl:with-param name="standard" select="'allow'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="error">
						<xsl:with-param name="msg">Standardized data categories can't be a member of the 'not available' profile.</xsl:with-param>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:if test="ancestor::dcif:dataCategory/@isocat:type='closed'">
			<xsl:if test="empty(ancestor::dcif:dataCategory//dcif:conceptualDomain[dcif:profile=current()])">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>The Data Category does not contain a conceptual domain for the profile '</xsl:text>
						<xsl:value-of select="."/>
						<xsl:text>' from which the Data Category is a member.</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:languageSection[dcif:language='en']" priority="1">
		<xsl:if test="empty(dcif:nameSection)">
			<xsl:call-template name="error">
				<xsl:with-param name="msg">The Data Category does not include the mandatory English (en) name section.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="empty(dcif:definitionSection)">
			<xsl:call-template name="error">
				<xsl:with-param name="msg">The Data Category does not include the mandatory English (en) definition.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="count(dcif:definitionSection) gt 1">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">Multiple definition sections in the language section for the language English (en).</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:languageSection">
		<xsl:if test="count(dcif:definitionSection) gt 1">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">
					<xsl:text>Multiple definition sections in the language section for the language </xsl:text>
					<xsl:value-of select="$languages//language[@tag=current()/dcif:language]/@name"/>
					<xsl:text> (</xsl:text>
					<xsl:value-of select="dcif:language"/>
					<xsl:text>).</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:languageSection/dcif:nameSection">
		<xsl:choose>
			<xsl:when test="empty(*)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified name section of the language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="empty(dcif:name)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified name in a name section of the language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="empty(dcif:nameStatus)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified name status in a name section of the language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:nameSection/dcif:name">
		<xsl:if test="normalize-space(.)=''">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">
					<xsl:text>Empty name in a name section of the language section for the language </xsl:text>
					<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
					<xsl:text> (</xsl:text>
					<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
					<xsl:text>).</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:nameSection/dcif:nameStatus">
		<xsl:if test="normalize-space(.)=''">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">
					<xsl:text>Empty name status in a name section of the language section for the language </xsl:text>
					<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
					<xsl:text> (</xsl:text>
					<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
					<xsl:text>).</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:languageSection/dcif:definitionSection">
		<xsl:choose>
			<xsl:when test="empty(*)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified definition section of the language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="empty(dcif:definition)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified definition in a definition section of the language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="empty(dcif:source)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified source in a definition section of the language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:definitionSection/dcif:definition">
		<xsl:if test="normalize-space(.)=''">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">
					<xsl:text>Empty definition in a definition section of the language section for the language </xsl:text>
					<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
					<xsl:text> (</xsl:text>
					<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
					<xsl:text>).</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:definitionSection/dcif:source">
		<xsl:if test="normalize-space(.)=''">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">
					<xsl:text>Empty source in a definition section of the language section for the language </xsl:text>
					<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
					<xsl:text> (</xsl:text>
					<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
					<xsl:text>).</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:languageSection/dcif:exampleSection">
		<xsl:choose>
			<xsl:when test="empty(*)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified example section of the language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="empty(dcif:example)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified example in an example section of the language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:languageSection/dcif:explanationSection">
		<xsl:choose>
			<xsl:when test="empty(*)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified explanation section of the language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="empty(dcif:explanation)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified explanation in an explanation section of the language section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:linguisticSection/dcif:exampleSection">
		<xsl:choose>
			<xsl:when test="empty(*)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified example section of the linguistic section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:linguisticSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:linguisticSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="empty(dcif:example)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified example in an example section of the linguistic section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:linguisticSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:linguisticSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:linguisticSection/dcif:explanationSection">
		<xsl:choose>
			<xsl:when test="empty(*)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified explanation section of the linguistic section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:linguisticSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:linguisticSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="empty(dcif:explanation)">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>Unspecified explanation in an explanation section of the linguistic section for the language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:linguisticSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:linguisticSection/dcif:language"/>
						<xsl:text>).</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:exampleSection/dcif:example">
		<xsl:if test="normalize-space(.)=''">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">
					<xsl:text>Empty example in an example section</xsl:text>
					<xsl:choose>
						<xsl:when test="exists(ancestor::dcif:languageSection)">
							<xsl:text> of the language section for the language </xsl:text>
							<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
							<xsl:text> (</xsl:text>
							<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
							<xsl:text>)</xsl:text>
						</xsl:when>
						<xsl:when test="exists(ancestor::dcif:linguisticSection)">
							<xsl:text> of the linguistic section for the language </xsl:text>
							<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:linguisticSection/dcif:language]/@name"/>
							<xsl:text> (</xsl:text>
							<xsl:value-of select="ancestor::dcif:linguisticSection/dcif:language"/>
							<xsl:text>)</xsl:text>
						</xsl:when>
					</xsl:choose>
					<xsl:text>.</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:explanantionSection/dcif:explanation">
		<xsl:if test="normalize-space(.)=''">
			<xsl:call-template name="error-or-warning">
				<xsl:with-param name="msg">
					<xsl:text>Empty explanation in an explanation section</xsl:text>
					<xsl:choose>
						<xsl:when test="exists(ancestor::dcif:languageSection)">
							<xsl:text> of the language section for the language </xsl:text>
							<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:languageSection/dcif:language]/@name"/>
							<xsl:text> (</xsl:text>
							<xsl:value-of select="ancestor::dcif:languageSection/dcif:language"/>
							<xsl:text>)</xsl:text>
						</xsl:when>
						<xsl:when test="exists(ancestor::dcif:linguisticSection)">
							<xsl:text> of the linguistic section for the language </xsl:text>
							<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:linguisticSection/dcif:language]/@name"/>
							<xsl:text> (</xsl:text>
							<xsl:value-of select="ancestor::dcif:linguisticSection/dcif:language"/>
							<xsl:text>)</xsl:text>
						</xsl:when>
					</xsl:choose>
					<xsl:text>.</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:conceptualDomain">
		<xsl:if test="@type='constrained' and empty(dcif:rule)">
			<xsl:call-template name="error">
				<xsl:with-param name="msg">The Data Category contains a constrained conceptual domain without any rules.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="@type='closed' and empty(dcif:value)">
			<xsl:call-template name="error">
				<xsl:with-param name="msg">The Data Category contains a closed conceptual domain without any reference to a simple Data Category.</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:conceptualDomain/dcif:profile">
		<xsl:if test="ancestor::dcif:dataCategory/@isocat:type='closed'">
			<xsl:if test="empty(ancestor::dcif:dataCategory/dcif:descriptionSection[dcif:profile=current()])">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>The Data Category does contain a conceptual domain for the profile '</xsl:text>
						<xsl:value-of select="."/>
						<xsl:text>' from which the Data Category is not a member.</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:value">
		<xsl:if test="@isocat:type!='simple'">
			<xsl:call-template name="fatal">
				<xsl:with-param name="msg">
					<xsl:text>Data Category contains a closed value domain with a reference to the complex Data Category '</xsl:text>
					<xsl:value-of select="@pid"/>
					<xsl:text>'.</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="parent::dcif:conceptualDomain[@type='closed'][exists(dcif:profile)][dcif:profile='undecided']">
			<xsl:if test="not(some $p in isocat:profile satisfies exists(parent::dcif:conceptualDomain[dcif:profile=$p]))">
				<xsl:call-template name="warning">
					<xsl:with-param name="msg">
						<xsl:text>The Data Category contains a 'undecided' profile specific closed value domain with a reference to the simple Data Category '</xsl:text>
						<xsl:value-of select="@pid"/>
						<xsl:text>' which is not a member of the 'undecided' profile.</xsl:text>
					</xsl:with-param>
					<xsl:with-param name="standard" select="'allow'"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:if test="parent::dcif:conceptualDomain[@type='closed'][exists(dcif:profile)][dcif:profile='not available']">
			<xsl:if test="not(some $p in isocat:profile satisfies exists(parent::dcif:conceptualDomain[dcif:profile=$p]))">
				<xsl:call-template name="warning">
					<xsl:with-param name="msg">
						<xsl:text>The Data Category contains a 'not available' profile specific closed value domain with a reference to the simple Data Category '</xsl:text>
						<xsl:value-of select="@pid"/>
						<xsl:text>' which is not a member of the 'not available' profile.</xsl:text>
					</xsl:with-param>
					<xsl:with-param name="standard" select="'allow'"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:if test="parent::dcif:conceptualDomain[@type='closed'][exists(dcif:profile)][not(dcif:profile=('undecided','not available'))]">
			<xsl:if test="not(some $p in isocat:profile satisfies exists(parent::dcif:conceptualDomain[dcif:profile=$p]))">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>The Data Category contains a profile specific closed value domain with a reference to the simple Data Category '</xsl:text>
						<xsl:value-of select="@pid"/>
						<xsl:text>' which is not a member of the profile '</xsl:text>
						<xsl:value-of select="parent::dcif:conceptualDomain/dcif:profile"/>
						<xsl:text>' of this conceptual domain.</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="not(some $p in isocat:profile satisfies exists(ancestor::dcif:dataCategory/dcif:descriptionSection[dcif:profile=$p]))">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>The Data Category contains a closed value domain with a reference to the simple Data Category '</xsl:text>
						<xsl:value-of select="@pid"/>
						<xsl:text>' which is not a member of any of the profiles this Data Category is a member of.</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:if test="ancestor::dcif:dataCategory/@isocat:scope='public' and @isocat:scope!='public'">
			<xsl:call-template name="warning">
				<xsl:with-param name="msg">
					<xsl:text>A conceptual domain of this public Data Category contains a reference to the private simple Data Category '</xsl:text>
					<xsl:value-of select="@pid"/>
					<xsl:text>'.</xsl:text>
				</xsl:with-param>
				<xsl:with-param name="standard" select="'allow'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:linguisticSection/dcif:conceptualDomain">
		<xsl:for-each select="dcif:value">
			<xsl:if test="empty(ancestor::dcif:dataCategory/dcif:conceptualDomain/dcif:value[@pid=current()/@pid])">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>The conceptual domain of the linguistic section for language </xsl:text>
						<xsl:value-of select="$languages//language[@tag=current()/ancestor::dcif:linguisticSection/dcif:language]/@name"/>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="ancestor::dcif:linguisticSection/dcif:language"/>
						<xsl:text>)</xsl:text>
						<xsl:text> contains a reference to the simple Data Category '</xsl:text>
						<xsl:value-of select="@pid"/>
						<xsl:text>' which is not a member of the defined conceptual domain of the Data Category.</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="dcif:isA">
		<xsl:if test="@isocat:type!=simple">
			<xsl:call-template name="fatal">
				<xsl:with-param name="msg">
					<xsl:text>The Data Category specification contains an is-a relationship with a complex Data Category '</xsl:text>
					<xsl:value-of select="@pid"/>
					<xsl:text>'.</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="ancestor::dcif:dataCategory/dcif:descriptionSection/dcif:profile='undecided'">
				<xsl:if test="not(isocat:profile='undecided')">
					<xsl:call-template name="warning">
						<xsl:with-param name="msg">
							<xsl:text>The simple Data Category, which is a member of the 'undecided' profile, has an is-a relationship with a simple Data Category '</xsl:text>
							<xsl:value-of select="@pid"/>
							<xsl:text>' which is not a member of the 'undecided' profile.</xsl:text>
						</xsl:with-param>
						<xsl:with-param name="standard" select="'allow'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="ancestor::dcif:dataCategory/dcif:descriptionSection/dcif:profile='not available'">
				<xsl:if test="not(isocat:profile='Private')">
					<xsl:call-template name="warning">
						<xsl:with-param name="msg">
							<xsl:text>The simple Data Category, which is a member of the 'not available' profile, has an is-a relationship with a simple Data Category '</xsl:text>
							<xsl:value-of select="@pid"/>
							<xsl:text>' which is not a member of the 'not available' profile.</xsl:text>
						</xsl:with-param>
						<xsl:with-param name="standard" select="'allow'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="not(some $p in isocat:profile satisfies exists(ancestor::dcif:dataCategory/dcif:descriptionSection[dcif:profile=$p]))">
				<xsl:call-template name="error">
					<xsl:with-param name="msg">
						<xsl:text>The simple Data Category has an is-a relationship with a simple Data Category '</xsl:text>
						<xsl:value-of select="@pid"/>
						<xsl:text>' which is not a member of any of the profiles this Data Category is a member of.</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:if test="ancestor::dcif:dataCategory/@isocat:scope='public' and @isocat:scope!='public'">
			<xsl:call-template name="error">
				<xsl:with-param name="msg">
					<xsl:text>This public simple Data Category has an is-a relationship with a private Data Category '</xsl:text>
					<xsl:value-of select="@pid"/>
					<xsl:text>'.</xsl:text>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>
	
	<!-- main -->

	<xsl:template match="/">
		<xsl:variable name="msgs">
			<xsl:apply-templates/>
		</xsl:variable>
		
		<xsl:variable name="result">
			<xsl:choose>
				<xsl:when test="exists($msgs/fatal)">
					<xsl:text>fatal</xsl:text>
				</xsl:when>
				<xsl:when test="exists($msgs/error)">
					<xsl:text>error</xsl:text>
				</xsl:when>
				<xsl:when test="exists($msgs/warning)">
					<xsl:text>warning</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>ok</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:message>INF: <xsl:value-of select="current-dateTime()"/>: checked <xsl:value-of select="if ($standard-flag) then ('candidate/standard ') else ()"/>DC[<xsl:value-of select="/dcif:dataCategorySelection/dcif:dataCategory/@isocat:id"/>][<xsl:value-of select="/dcif:dataCategorySelection/dcif:dataCategory/@isocat:owner"/>-<xsl:value-of select="/dcif:dataCategorySelection/dcif:dataCategory/dcif:administrationInformationSection/dcif:administrationRecord/dcif:identifier"/>-<xsl:value-of select="/dcif:dataCategorySelection/dcif:dataCategory/dcif:administrationInformationSection/dcif:administrationRecord/dcif:version"/>][<xsl:value-of select="/dcif:dataCategorySelection/dcif:dataCategory/@isocat:name"/>] result[<xsl:value-of select="$result"/>]</xsl:message>
		
		<check result="{$result}" flags="{if ($standard-flag) then ('standard') else ()}">
			<xsl:copy-of select="$msgs"/>
		</check>
	</xsl:template>

</xsl:stylesheet>
